'use strict';

import React, {
  Component,
  View,
  WebView
} from 'react-native';

import AddressBar from './src/AddressBar';
import styles from './src/styles';

const WEBVIEW_REF = 'webview';

export default class WebBrowser extends Component {
  constructor(props) {
    super(props);
    this.state = {
      url: this.props.url,
      backButtonEnabled: false,
      forwardButtonEnabled: false,
      loading: true,
      scalesPageToFit: true,
    };
  }

  componentWillReceiveProps(nextProps) {
    this.setState({
      url: nextProps.url
    });
  }

  goBack() {
    this.refs[WEBVIEW_REF].goBack();
  }

  goForward() {
    this.refs[WEBVIEW_REF].goForward();
  }

  load(url) {
    this.setState({
      url
    });
  }

  reload() {
    this.refs[WEBVIEW_REF].reload();
  }

  onNavigationStateChange(nevigationState) {
    this.setState({
      backButtonEnabled: navigationState.canGoBack,
      forwardButtonEnabled: navigationState.canGoForward,
      url: navigationState.url,
      title: navigationState.title,
      loading: navigationState.loading,
      scalesPageToFit: true
    });
    console.log(navigationState);
  }

  render() {
    return (
      <View style={styles.container}>
        <View style={styles.header}>
          <AddressBar
            url={this.state.url}
            onBack={this.goBack.bind(this)}
            onForward={this.goForward.bind(this)}
            onReload={this.reload.bind(this)}
            onLoad={(url)=>{this.load(url)}}
          />
        </View>
        <WebView
          ref={WEBVIEW_REF}
          automaticallyAdjustContentInsets={false}
          style={styles.webView}
          source={{ uri: this.state.url }}
          javaScriptEnabled={true}
          domStorageEnabled={true}
          startInLoadingState={true}
          decelerationRate="normal"
          onNavigationStateChange={this.onNavigationStateChange.bind(this)}
        />
      </View>
    );
  }
}
